==> estateplat-common-1.2.4-20220607.092754-1035-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptBdcqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_bdcqk")
public class GxTcJcptBdcqk {
    @Id
    private String ywid;
    private String bjbh;
    private String bdcqzmh;
    private String bdcqzsh;
    private String bdcdyh;
    private String zl;
    private Integer fwyt;
    private Double fwmj;
    private String tdyt;
    private Double tdmj;
    private Integer qlxz;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }

    public String getBdcqzsh() {
        return bdcqzsh;
    }

    public void setBdcqzsh(String bdcqzsh) {
        this.bdcqzsh = bdcqzsh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Integer getFwyt() {
        return fwyt;
    }

    public void setFwyt(Integer fwyt) {
        this.fwyt = fwyt;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public Integer getQlxz() {
        return qlxz;
    }

    public void setQlxz(Integer qlxz) {
        this.qlxz = qlxz;
    }
}

==> estateplat-common-1.2.4-20220611.103503-1038-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptBdcqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_bdcqk")
public class GxTcJcptBdcqk {
    @Id
    private String ywid;
    private String bjbh;
    private String bdcqzmh;
    private String bdcqzsh;
    private String bdcdyh;
    private String zl;
    private Integer fwyt;
    private Double fwmj;
    private String tdyt;
    private Double tdmj;
    private Integer qlxz;
    private String tdsyqssj;
    private String tdsyjssj;
    private String bdcdjfj;
    private String bdcjybh;
    private String bdcjywszmh;
    private String bdcjyjg;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }

    public String getBdcqzsh() {
        return bdcqzsh;
    }

    public void setBdcqzsh(String bdcqzsh) {
        this.bdcqzsh = bdcqzsh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Integer getFwyt() {
        return fwyt;
    }

    public void setFwyt(Integer fwyt) {
        this.fwyt = fwyt;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public Integer getQlxz() {
        return qlxz;
    }

    public void setQlxz(Integer qlxz) {
        this.qlxz = qlxz;
    }

    public String getTdsyqssj() {
        return tdsyqssj;
    }

    public void setTdsyqssj(String tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public String getTdsyjssj() {
        return tdsyjssj;
    }

    public void setTdsyjssj(String tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public String getBdcdjfj() {
        return bdcdjfj;
    }

    public void setBdcdjfj(String bdcdjfj) {
        this.bdcdjfj = bdcdjfj;
    }

    public String getBdcjybh() {
        return bdcjybh;
    }

    public void setBdcjybh(String bdcjybh) {
        this.bdcjybh = bdcjybh;
    }

    public String getBdcjywszmh() {
        return bdcjywszmh;
    }

    public void setBdcjywszmh(String bdcjywszmh) {
        this.bdcjywszmh = bdcjywszmh;
    }

    public String getBdcjyjg() {
        return bdcjyjg;
    }

    public void setBdcjyjg(String bdcjyjg) {
        this.bdcjyjg = bdcjyjg;
    }
}
